#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""

   Copyright 2014-2020 OpenEEmeter contributors

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

"""
__title__ = "gsecrets"
__description__ = "API and CLI for securely managing secrets"
__url__ = "https://github.com/openeemeter/gsecrets"
__version__ = "1.3.1"
__author__ = "Recurve"
__author_email__ = "admin@recurve.com"
__license__ = "Apache 2.0"
__copyright__ = "Copyright 2014-2020 OpenEEmeter contributors"
